@@ -10,7 +10,7 @@ import subprocess
 """
 ClockWorks
 Author: Jacob Vlijm
-Copyright © 2017-2021 Ubuntu Budgie Developers
+Copyright © 2017 Ubuntu Budgie Developers
 Website=https://ubuntubudgie.org
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -22,15 +22,6 @@ should have received a copy of the GNU General Public License along with this
 program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-tz_data = [
-    "-12:00", "-11:00", "-10:00", "-09:30", "-09:00", "-08:00", "-07:00",
-    "-06:00", "-05:00", "-04:00", "-03:30", "-03:00", "-02:00", "-01:00",
-    "00:00", "+01:00", "+02:00", "+03:00", "+03:30", "+04:00", "+04:30",
-    "+05:00", "+05:30", "+05:45", "+06:00", "+06:30", "+07:00", "+08:00",
-    "+08:30", "+08:45", "+09:00", "+09:30", "+10:00", "+10:30", "+11:00",
-    "+12:00", "+12:45", "+13:00", "+14:00",
-]
-
 
 def get(command):
     try:
